.. mainf.core.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2012 Róbert Čerňanský



.. A section for the AutoArchive._mainf._core package.



AutoArchive._mainf._core
========================

.. automodule:: AutoArchive._mainf._core
   :no-members:



Modules
-------

mainf_engine
^^^^^^^^^^^^

.. automodule:: AutoArchive._mainf._core.mainf_engine



_interface_accessor
^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._mainf._core._interface_accessor
.. autoclass:: _InterfaceAccessor



_mainf_context
^^^^^^^^^^^^^^

.. automodule:: AutoArchive._mainf._core._mainf_context
.. autoclass:: _MainfContext
